@@ -15,7 +15,7 @@ import pandas as pd
 
 class GSDBS:
     def __init__(self, creadPath):
-        self.version = "0.1.25"
+        self.version = "0.1.27"
         self.credentials = None
         self.accessToken = None
         self.dtablename = None
@@ -250,7 +250,6 @@ class GSDBS:
             f"""mutation {{\n\taddDTable(dtablename: "{self.dtablename}", \n\t\tsuperDTable: [{self.superdtablename}], \n\t\tsriBuildInfo: "{buildInfo}", \n\t\tdataLinks: [\n{dataSchema}\n\t\t], \n\t\tdata: [\n{self.getData()}\t\t]\n\t)\n}}"""
         return
 
-    # ---------
     async def asyncSchemaCheck(self):
         # check mutation content
         rc = self.checkDTableName()
@@ -304,7 +303,6 @@ class GSDBS:
                 return link['type']['name']
         return None
 
-    # ---------
     async def asyncAddDObject(self, dtablename, sribuildinfo, dataframe, superdtablename="DTABLE", schemaCheck=True):
         self.superdtablename = superdtablename
         rc = self.setDTableName(dtablename)
@@ -355,7 +353,6 @@ class GSDBS:
 
         return rc
 
-    # ---------
     async def asyncSchemaQuery(self, dtablename):
         statement = "{ __type(name: \"" + dtablename + "\") {name fields { name type { name kind } } } }"
 
@@ -378,7 +375,6 @@ class GSDBS:
 
         return result
 
-    # ---------
     async def asyncExecuteStatement(self, statement=None):
         if statement == None:
             if self.statement == None: return -9
@@ -387,9 +383,8 @@ class GSDBS:
             query = gql(statement)
 
         api_call_headers = {'Authorization': 'Bearer ' + self.accessToken['access_token']}
-        client = Client(transport=AIOHTTPTransport(url="https://glass-sphere-ai.de/gsgraphql",
-                                                   headers=api_call_headers),
-                        headers=api_call_headers, timeout=3600)
+        client = Client(transport=AIOHTTPTransport(url="https://glass-sphere-ai.de/gsgraphql", headers=api_call_headers, timeout=3600),
+                        fetch_schema_from_transport=False)
 
         try:
             result = await client.execute_async(query)
@@ -407,8 +402,7 @@ class GSDBS:
             query = gql(statement)
 
         api_call_headers = {'Authorization': 'Bearer ' + self.accessToken['access_token']}
-        client = Client(transport=AIOHTTPTransport(url="https://glass-sphere-ai.de/gsgraphql",
-                                                   headers=api_call_headers, timeout=3600),
+        client = Client(transport=AIOHTTPTransport(url="https://glass-sphere-ai.de/gsgraphql", headers=api_call_headers, timeout=3600),
                         fetch_schema_from_transport=False)
 
         try:
@@ -419,17 +413,16 @@ class GSDBS:
 
         return result
 
-        async def asyncDropDTable(self, dtablename):
-            statement = f"""mutation {{\n\tdropDTable(dtablename: {dtablename})\n}}"""
-            result = await self.asyncExecuteStatement(statement)
-            return result
+    async def asyncDropDTable(self, dtablename):
+        statement = f"""mutation {{\n\tdropDTable(dtablename: {dtablename})\n}}"""
+        result = await self.asyncExecuteStatement(statement)
+        return result
 
     def dropDTable(self, dtablename):
         statement = f"""mutation {{\n\tdropDTable(dtablename: {dtablename})\n}}"""
         result = self.executeStatement(statement)
         return result
 
-
     def getDTableFullQuery(self, dtablename):
         try:
             self.querybuffer = 'query {\n'
